ClusterRegisterArray

Struct ClusterRegisterArray 

pub struct ClusterRegisterArray<T: Sized, const DIM: usize, const DIM_INCREMENT: usize> { /* private fields */ }
An array of identical register clusters.

Implementations

Source

impl<T: Sized, const DIM: usize, const DIM_INCREMENT: usize> ClusterRegisterArray<T, DIM, DIM_INCREMENT>

pub const fn len(&self) -> usize

Returns the number of register blocks in the cluster.

pub const fn is_empty(&self) -> bool

Returns whether the cluster is empty (DIM == 0).

pub fn iter(&self) -> impl ExactSizeIterator<Item = &T>

Returns an iterator over the elements of this cluster.

pub const fn get(&self, index: usize) -> &T

Returns the cluster element with the specified index.

Panics if the index is out of bounds.

pub const unsafe fn get_unchecked(&self, index: usize) -> &T

Returns the cluster element with the specified index.

Safety

index must be less than DIM.