Cec

Struct Cec 

pub struct Cec { /* private fields */ }

Implementations

Source

impl Cec

pub const fn cadr(&self) -> &'static Reg<Cadr_SPEC, RW>

CEC Local Address Setting Register

pub const fn cecctl1(&self) -> &'static Reg<Cecctl1_SPEC, RW>

CEC Control Register 1

pub const fn statb(&self) -> &'static Reg<Statb_SPEC, RW>

CEC Transmission Start Bit Width Setting Register

pub const fn statl(&self) -> &'static Reg<Statl_SPEC, RW>

CEC Transmission Start Bit Low Width Setting Register

pub const fn lgc0l(&self) -> &'static Reg<Lgc0L_SPEC, RW>

CEC Transmission Logical 0 Low Width Setting Register

pub const fn lgc1l(&self) -> &'static Reg<Lgc1L_SPEC, RW>

CEC Transmission Logical 1 Low Width Setting Register

pub const fn datb(&self) -> &'static Reg<Datb_SPEC, RW>

CEC Transmission Data Bit Width Setting Register

pub const fn nomt(&self) -> &'static Reg<Nomt_SPEC, RW>

CEC Reception Data Sampling Time Setting Register

pub const fn statll(&self) -> &'static Reg<Statll_SPEC, RW>

CEC Reception Start Bit Minimum Low Width Setting Register

pub const fn statlh(&self) -> &'static Reg<Statlh_SPEC, RW>

CEC Reception Start Bit Maximum Low Width Setting Register

pub const fn statbl(&self) -> &'static Reg<Statbl_SPEC, RW>

CEC Reception Start Bit Minimum Bit Width Setting Register

pub const fn statbh(&self) -> &'static Reg<Statbh_SPEC, RW>

CEC Reception Start Bit Maximum Bit Width Setting Register

pub const fn lgc0ll(&self) -> &'static Reg<Lgc0Ll_SPEC, RW>

CEC Reception Logical 0 Minimum Low Width Setting Register

pub const fn lgc0lh(&self) -> &'static Reg<Lgc0Lh_SPEC, RW>

CEC Reception Logical 0 Maximum Low Width Setting Register

pub const fn lgc1ll(&self) -> &'static Reg<Lgc1Ll_SPEC, RW>

CEC Reception Logical 1 Minimum Low Width Setting Register

pub const fn lgc1lh(&self) -> &'static Reg<Lgc1Lh_SPEC, RW>

CEC Reception Logical 1 Maximum Low Width Setting Register

pub const fn datbl(&self) -> &'static Reg<Datbl_SPEC, RW>

CEC Reception Data Bit Minimum Bit Width Setting Register

pub const fn datbh(&self) -> &'static Reg<Datbh_SPEC, RW>

CEC Reception Data Bit Maximum Bit Width Setting Register

pub const fn nomp(&self) -> &'static Reg<Nomp_SPEC, RW>

CEC Data Bit Reference Width Setting Register

pub const fn cecexmd(&self) -> &'static Reg<Cecexmd_SPEC, RW>

CEC Extension Mode Register

pub const fn cecexmon(&self) -> &'static Reg<Cecexmon_SPEC, RW>

CEC Extension Monitor Register

pub const fn ctxd(&self) -> &'static Reg<Ctxd_SPEC, RW>

CEC Transmission Buffer Register

pub const fn crxd(&self) -> &'static Reg<Crxd_SPEC, RW>

CEC Reception Buffer Register

pub const fn ceces(&self) -> &'static Reg<Ceces_SPEC, RW>

CEC Communication Error Status Register

pub const fn cecs(&self) -> &'static Reg<Cecs_SPEC, RW>

CEC Communication Status Register

pub const fn cecfc(&self) -> &'static Reg<Cecfc_SPEC, RW>

CEC Communication Error Flag Clear Trigger Register

pub const fn cecctl0(&self) -> &'static Reg<Cecctl0_SPEC, RW>

CEC Control Register 0