Sci0

Struct Sci0 

pub struct Sci0 { /* private fields */ }

Implementations

Source

impl Sci0

pub const fn smr(&self) -> &'static Reg<Smr_SPEC, RW>

Serial Mode Register for Non-Smart Card Interface Mode (SCMR.SMIF = 0)

pub const fn smr_smci(&self) -> &'static Reg<SmrSmci_SPEC, RW>

Serial Mode Register for Smart Card Interface Mode (SCMR.SMIF = 1)

pub const fn brr(&self) -> &'static Reg<Brr_SPEC, RW>

Bit Rate Register

pub const fn scr(&self) -> &'static Reg<Scr_SPEC, RW>

Serial Control Register for Non-Smart Card Interface Mode (SCMR.SMIF = 0)

pub const fn scr_smci(&self) -> &'static Reg<ScrSmci_SPEC, RW>

Serial Control Register for Smart Card Interface Mode (SCMR.SMIF = 1)

pub const fn tdr(&self) -> &'static Reg<Tdr_SPEC, RW>

Transmit Data Register

pub const fn ssr(&self) -> &'static Reg<Ssr_SPEC, RW>

Serial Status Register for Non-Smart Card Interface and Non-FIFO Mode (SCMR.SMIF = 0, FCR.FM = 0, and MMR.MANEN = 0)

pub const fn ssr_fifo(&self) -> &'static Reg<SsrFifo_SPEC, RW>

Serial Status Register for Non-Smart Card Interface and FIFO Mode (SCMR.SMIF = 0, FCR.FM = 1, and MMR.MANEN = 0)

pub const fn ssr_manc(&self) -> &'static Reg<SsrManc_SPEC, RW>

Serial Status Register for Manchester Mode (SCMR.SMIF = 0, and MMR.MANEN = 1)

pub const fn ssr_smci(&self) -> &'static Reg<SsrSmci_SPEC, RW>

Serial Status Register for Smart Card Interface Mode (SCMR.SMIF = 1, and MMR.MANEN = 0)

pub const fn rdr(&self) -> &'static Reg<Rdr_SPEC, R>

Receive Data Register

pub const fn scmr(&self) -> &'static Reg<Scmr_SPEC, RW>

Smart Card Mode Register

pub const fn semr(&self) -> &'static Reg<Semr_SPEC, RW>

Serial Extended Mode Register

pub const fn snfr(&self) -> &'static Reg<Snfr_SPEC, RW>

Noise Filter Setting Register

pub const fn simr1(&self) -> &'static Reg<Simr1_SPEC, RW>

IIC Mode Register 1

pub const fn simr2(&self) -> &'static Reg<Simr2_SPEC, RW>

IIC Mode Register 2

pub const fn simr3(&self) -> &'static Reg<Simr3_SPEC, RW>

IIC Mode Register 3

pub const fn sisr(&self) -> &'static Reg<Sisr_SPEC, R>

IIC Status Register

pub const fn spmr(&self) -> &'static Reg<Spmr_SPEC, RW>

SPI Mode Register

pub const fn ftdrhl(&self) -> &'static Reg<Ftdrhl_SPEC, W>

Transmit FIFO Data Register

pub const fn tdrhl(&self) -> &'static Reg<Tdrhl_SPEC, RW>

Transmit Data Register for Non-Manchester mode (MMR.MANEN = 0)

pub const fn tdrhl_man(&self) -> &'static Reg<TdrhlMan_SPEC, RW>

Transmit Data Register for Manchester mode (MMR.MANEN = 1)

pub const fn ftdrh(&self) -> &'static Reg<Ftdrh_SPEC, W>

Transmit FIFO Data Register

pub const fn ftdrl(&self) -> &'static Reg<Ftdrl_SPEC, W>

Transmit FIFO Data Register

pub const fn frdrhl(&self) -> &'static Reg<Frdrhl_SPEC, R>

Receive FIFO Data Register

pub const fn rdrhl(&self) -> &'static Reg<Rdrhl_SPEC, R>

Receive Data Register for Non-Manchester mode (MMR.MANEN = 0)

pub const fn rdrhl_man(&self) -> &'static Reg<RdrhlMan_SPEC, R>

Receive Data Register for Manchester mode (MMR.MANEN = 1)

pub const fn frdrh(&self) -> &'static Reg<Frdrh_SPEC, R>

Receive FIFO Data Register

pub const fn frdrl(&self) -> &'static Reg<Frdrl_SPEC, R>

Receive FIFO Data Register

pub const fn mddr(&self) -> &'static Reg<Mddr_SPEC, RW>

Modulation Duty Register

pub const fn dccr(&self) -> &'static Reg<Dccr_SPEC, RW>

Data Compare Match Control Register

pub const fn fcr(&self) -> &'static Reg<Fcr_SPEC, RW>

FIFO Control Register

pub const fn fdr(&self) -> &'static Reg<Fdr_SPEC, R>

FIFO Data Count Register

pub const fn lsr(&self) -> &'static Reg<Lsr_SPEC, R>

Line Status Register

pub const fn cdr(&self) -> &'static Reg<Cdr_SPEC, RW>

Compare Match Data Register

pub const fn sptr(&self) -> &'static Reg<Sptr_SPEC, RW>

Serial Port Register

pub const fn actr(&self) -> &'static Reg<Actr_SPEC, RW>

Adjustment Communication Timing Register

pub const fn mmr(&self) -> &'static Reg<Mmr_SPEC, RW>

Manchester Mode Register

pub const fn tmpr(&self) -> &'static Reg<Tmpr_SPEC, RW>

Transmit Manchester Preface Setting Register

pub const fn rmpr(&self) -> &'static Reg<Rmpr_SPEC, RW>

Receive Manchester Preface Setting Register

pub const fn mesr(&self) -> &'static Reg<Mesr_SPEC, RW>

Manchester Extended Error Status Register

pub const fn mecr(&self) -> &'static Reg<Mecr_SPEC, RW>

Manchester Extended Error Control Register