Deepcut

Type Alias Deepcut 

pub type Deepcut = EnumBitfieldStruct<u8, Deepcut_SPEC>;

Aliased Type

#[repr(transparent)]
pub struct Deepcut(pub u8, _);

Tuple Fields

0: u8

Implementations

Source

impl Deepcut

pub const _00: Self

Power to the standby RAM, Low-speed on-chip oscillator, AGTn (n = 0, 1), and USBFS resume detecting unit is supplied in Deep Software Standby mode.

pub const _01: Self

Power to the standby RAM, Low-speed on-chip oscillator, AGT, and USBFS resume detecting unit is not supplied in Deep Software Standby mode.

pub const _10: Self

Setting prohibited

pub const _11: Self

Power to the standby RAM, Low-speed on-chip oscillator, AGT, and USBFS resume detecting unit is not supplied in Deep Software Standby mode. In addition, LVD is disabled and the low power function in a power-on reset circuit is enabled.