Dpfsar

Type Alias Dpfsar 

pub type Dpfsar = RegValueT<Dpfsar_SPEC>;
Deep Standby Interrupt Factor Security Attribution Register

Aliased Type

pub struct Dpfsar { /* private fields */ }

Implementations

Source

impl Dpfsar

pub fn dpfsa0( self, ) -> RegisterField<0, 0x1, 1, 0, Dpfsa0, Dpfsa0, Dpfsar_SPEC, RW>

Deep Standby Interrupt Factor Security Attribute bit 0

pub fn dpfsa1( self, ) -> RegisterField<1, 0x1, 1, 0, Dpfsa1, Dpfsa1, Dpfsar_SPEC, RW>

Deep Standby Interrupt Factor Security Attribute bit 1

pub fn dpfsa04( self, ) -> RegisterField<4, 0x1, 1, 0, Dpfsa04, Dpfsa04, Dpfsar_SPEC, RW>

Deep Standby Interrupt Factor Security Attribute bit n (n = 4 to 12)

pub fn dpfsa05( self, ) -> RegisterField<5, 0x1, 1, 0, Dpfsa05, Dpfsa05, Dpfsar_SPEC, RW>

Deep Standby Interrupt Factor Security Attribute bit n (n = 4 to 12)

pub fn dpfsa06( self, ) -> RegisterField<6, 0x1, 1, 0, Dpfsa06, Dpfsa06, Dpfsar_SPEC, RW>

Deep Standby Interrupt Factor Security Attribute bit n (n = 4 to 12)

pub fn dpfsa07( self, ) -> RegisterField<7, 0x1, 1, 0, Dpfsa07, Dpfsa07, Dpfsar_SPEC, RW>

Deep Standby Interrupt Factor Security Attribute bit n (n = 4 to 12)

pub fn dpfsa08( self, ) -> RegisterField<8, 0x1, 1, 0, Dpfsa08, Dpfsa08, Dpfsar_SPEC, RW>

Deep Standby Interrupt Factor Security Attribute bit n (n = 4 to 12)

pub fn dpfsa09( self, ) -> RegisterField<9, 0x1, 1, 0, Dpfsa09, Dpfsa09, Dpfsar_SPEC, RW>

Deep Standby Interrupt Factor Security Attribute bit n (n = 4 to 12)

pub fn dpfsa10( self, ) -> RegisterField<10, 0x1, 1, 0, Dpfsa10, Dpfsa10, Dpfsar_SPEC, RW>

Deep Standby Interrupt Factor Security Attribute bit n (n = 4 to 12)

pub fn dpfsa11( self, ) -> RegisterField<11, 0x1, 1, 0, Dpfsa11, Dpfsa11, Dpfsar_SPEC, RW>

Deep Standby Interrupt Factor Security Attribute bit n (n = 4 to 12)

pub fn dpfsa12( self, ) -> RegisterField<12, 0x1, 1, 0, Dpfsa12, Dpfsa12, Dpfsar_SPEC, RW>

Deep Standby Interrupt Factor Security Attribute bit n (n = 4 to 12)

pub fn dpfsa14( self, ) -> RegisterField<14, 0x1, 1, 0, Dpfsa14, Dpfsa14, Dpfsar_SPEC, RW>

Deep Standby Interrupt Factor Security Attribute bit 14

pub fn dpfsa16( self, ) -> RegisterField<16, 0x1, 1, 0, Dpfsa16, Dpfsa16, Dpfsar_SPEC, RW>

Deep Standby Interrupt Factor Security Attribute bit 16

pub fn dpfsa17( self, ) -> RegisterField<17, 0x1, 1, 0, Dpfsa17, Dpfsa17, Dpfsar_SPEC, RW>

Deep Standby Interrupt Factor Security Attribute bit 17

pub fn dpfsa18( self, ) -> RegisterField<18, 0x1, 1, 0, Dpfsa18, Dpfsa18, Dpfsar_SPEC, RW>

Deep Standby Interrupt Factor Security Attribute bit 18

pub fn dpfsa19( self, ) -> RegisterField<19, 0x1, 1, 0, Dpfsa19, Dpfsa19, Dpfsar_SPEC, RW>

Deep Standby Interrupt Factor Security Attribute bit 19

pub fn dpfsa20( self, ) -> RegisterField<20, 0x1, 1, 0, Dpfsa20, Dpfsa20, Dpfsar_SPEC, RW>

Deep Standby Interrupt Factor Security Attribute bit 20

pub fn dpfsa24( self, ) -> RegisterField<24, 0x1, 1, 0, Dpfsa24, Dpfsa24, Dpfsar_SPEC, RW>

Deep Standby Interrupt Factor Security Attribute bit 24

pub fn dpfsa26( self, ) -> RegisterField<26, 0x1, 1, 0, Dpfsa26, Dpfsa26, Dpfsar_SPEC, RW>

Deep Standby Interrupt Factor Security Attribute bit 26