pub type Prcr = RegValueT<Prcr_SPEC>;Expand description
Protect Register
Aliased Type
pub struct Prcr { /* private fields */ }Implementations
Sourceimpl Prcr
impl Prcr
Sourcepub fn prc0(self) -> RegisterField<0, 0x1, 1, 0, Prc0, Prc0, Prcr_SPEC, RW>
pub fn prc0(self) -> RegisterField<0, 0x1, 1, 0, Prc0, Prc0, Prcr_SPEC, RW>
Enable writing to the registers related to the clock generation circuit
Sourcepub fn prc1(self) -> RegisterField<1, 0x1, 1, 0, Prc1, Prc1, Prcr_SPEC, RW>
pub fn prc1(self) -> RegisterField<1, 0x1, 1, 0, Prc1, Prc1, Prcr_SPEC, RW>
Enable writing to the registers related to the low power modes
Sourcepub fn prc3(self) -> RegisterField<3, 0x1, 1, 0, Prc3, Prc3, Prcr_SPEC, RW>
pub fn prc3(self) -> RegisterField<3, 0x1, 1, 0, Prc3, Prc3, Prcr_SPEC, RW>
Enable writing to the registers related to the LVD