pub struct RegisterFieldBool<const START_OFFSET: usize, const DIM: u8, const DIM_INCREMENT: u8, T, A>where
T: RegSpec,
A: Access,{ /* private fields */ }Expand description
Proxy struct for boolean bitfields
Implementations
Sourceimpl<const START_OFFSET: usize, const DIM: u8, const DIM_INCREMENT: u8, T, A> RegisterFieldBool<START_OFFSET, DIM, DIM_INCREMENT, T, A>where
T: RegSpec,
A: Read,
impl<const START_OFFSET: usize, const DIM: u8, const DIM_INCREMENT: u8, T, A> RegisterFieldBool<START_OFFSET, DIM, DIM_INCREMENT, T, A>where
T: RegSpec,
A: Read,
Sourceimpl<const START_OFFSET: usize, const DIM: u8, const DIM_INCREMENT: u8, T, A> RegisterFieldBool<START_OFFSET, DIM, DIM_INCREMENT, T, A>where
T: RegSpec,
A: Write,
impl<const START_OFFSET: usize, const DIM: u8, const DIM_INCREMENT: u8, T, A> RegisterFieldBool<START_OFFSET, DIM, DIM_INCREMENT, T, A>where
T: RegSpec,
A: Write,
Sourcepub fn set(self, value: bool) -> RegValueT<T>
pub fn set(self, value: bool) -> RegValueT<T>
Prepare bitfield value to be written to register
Example
ⓘ
// example with generic names
// get an instance by reading
let values = TIMER.bitfield_reg().read();
// or by starting with a known value
let value = timer::BitfieldReg::new(0);
// or by starting with the default
let value = timer::BitfieldReg::default();
// set bitfield
let value = value
.boolrw()
.set(true);
// up until now no hardware change has taken place, do that now by writing
TIMER.bitfield_reg().write(value);Sourceimpl<const START_OFFSET: usize, const DIM: u8, const DIM_INCREMENT: u8, T, A> RegisterFieldBool<START_OFFSET, DIM, DIM_INCREMENT, T, A>where
T: RegSpec,
A: Access,
impl<const START_OFFSET: usize, const DIM: u8, const DIM_INCREMENT: u8, T, A> RegisterFieldBool<START_OFFSET, DIM, DIM_INCREMENT, T, A>where
T: RegSpec,
A: Access,
Sourcepub fn mask(&self) -> T::DataType
pub fn mask(&self) -> T::DataType
Get mask for bitfield, the mask is unshifted and at offset 0
Prefer the use of RegisterField<START_OFFSET, MASK, DIM, DIM_INCREMENT, ValueType, T, A>::get() to
extract a bitfield value.
Sourcepub const fn offset(&self) -> usize
pub const fn offset(&self) -> usize
Get offset of bitfield in containing register
Prefer the use of RegisterField<START_OFFSET, MASK, DIM, DIM_INCREMENT, ValueType, T, A>::get() to
extract a bitfield value.