pub struct Sci0 { /* private fields */ }Implementations
Sourceimpl Sci0
impl Sci0
Sourcepub const fn smr(&self) -> &'static Reg<Smr_SPEC, RW>
pub const fn smr(&self) -> &'static Reg<Smr_SPEC, RW>
Serial Mode Register for Non-Smart Card Interface Mode (SCMR.SMIF = 0)
Sourcepub const fn smr_smci(&self) -> &'static Reg<SmrSmci_SPEC, RW>
pub const fn smr_smci(&self) -> &'static Reg<SmrSmci_SPEC, RW>
Serial Mode Register for Smart Card Interface Mode (SCMR.SMIF = 1)
Sourcepub const fn scr(&self) -> &'static Reg<Scr_SPEC, RW>
pub const fn scr(&self) -> &'static Reg<Scr_SPEC, RW>
Serial Control Register for Non-Smart Card Interface Mode (SCMR.SMIF = 0)
Sourcepub const fn scr_smci(&self) -> &'static Reg<ScrSmci_SPEC, RW>
pub const fn scr_smci(&self) -> &'static Reg<ScrSmci_SPEC, RW>
Serial Control Register for Smart Card Interface Mode (SCMR.SMIF = 1)
Sourcepub const fn ssr(&self) -> &'static Reg<Ssr_SPEC, RW>
pub const fn ssr(&self) -> &'static Reg<Ssr_SPEC, RW>
Serial Status Register for Non-Smart Card Interface and Non-FIFO Mode (SCMR.SMIF = 0, FCR.FM = 0, and MMR.MANEN = 0)
Sourcepub const fn ssr_fifo(&self) -> &'static Reg<SsrFifo_SPEC, RW>
pub const fn ssr_fifo(&self) -> &'static Reg<SsrFifo_SPEC, RW>
Serial Status Register for Non-Smart Card Interface and FIFO Mode (SCMR.SMIF = 0, FCR.FM = 1, and MMR.MANEN = 0)
Sourcepub const fn ssr_manc(&self) -> &'static Reg<SsrManc_SPEC, RW>
pub const fn ssr_manc(&self) -> &'static Reg<SsrManc_SPEC, RW>
Serial Status Register for Manchester Mode (SCMR.SMIF = 0, and MMR.MANEN = 1)
Sourcepub const fn ssr_smci(&self) -> &'static Reg<SsrSmci_SPEC, RW>
pub const fn ssr_smci(&self) -> &'static Reg<SsrSmci_SPEC, RW>
Serial Status Register for Smart Card Interface Mode (SCMR.SMIF = 1, and MMR.MANEN = 0)
Sourcepub const fn tdrhl(&self) -> &'static Reg<Tdrhl_SPEC, RW>
pub const fn tdrhl(&self) -> &'static Reg<Tdrhl_SPEC, RW>
Transmit Data Register for Non-Manchester mode (MMR.MANEN = 0)
Sourcepub const fn tdrhl_man(&self) -> &'static Reg<TdrhlMan_SPEC, RW>
pub const fn tdrhl_man(&self) -> &'static Reg<TdrhlMan_SPEC, RW>
Transmit Data Register for Manchester mode (MMR.MANEN = 1)
Sourcepub const fn rdrhl(&self) -> &'static Reg<Rdrhl_SPEC, R>
pub const fn rdrhl(&self) -> &'static Reg<Rdrhl_SPEC, R>
Receive Data Register for Non-Manchester mode (MMR.MANEN = 0)
Sourcepub const fn rdrhl_man(&self) -> &'static Reg<RdrhlMan_SPEC, R>
pub const fn rdrhl_man(&self) -> &'static Reg<RdrhlMan_SPEC, R>
Receive Data Register for Manchester mode (MMR.MANEN = 1)
Sourcepub const fn actr(&self) -> &'static Reg<Actr_SPEC, RW>
pub const fn actr(&self) -> &'static Reg<Actr_SPEC, RW>
Adjustment Communication Timing Register
Sourcepub const fn tmpr(&self) -> &'static Reg<Tmpr_SPEC, RW>
pub const fn tmpr(&self) -> &'static Reg<Tmpr_SPEC, RW>
Transmit Manchester Preface Setting Register
Sourcepub const fn rmpr(&self) -> &'static Reg<Rmpr_SPEC, RW>
pub const fn rmpr(&self) -> &'static Reg<Rmpr_SPEC, RW>
Receive Manchester Preface Setting Register