Type Alias Dpsier2

pub type Dpsier2 = RegValueT<Dpsier2_SPEC>;
Deep Software Standby Interrupt Enable Register 2

Aliased Type

struct Dpsier2 { /* private fields */ }

Implementations

Source

impl Dpsier2

pub fn dlvd1ie(self) -> RegisterField<0, 0x1, 1, 0, Dlvd1Ie, Dpsier2_SPEC, RW>

LVD1 Deep Software Standby Cancel Signal Enable

pub fn dlvd2ie(self) -> RegisterField<1, 0x1, 1, 0, Dlvd2Ie, Dpsier2_SPEC, RW>

LVD2 Deep Software Standby Cancel Signal Enable

pub fn drtciie(self) -> RegisterField<2, 0x1, 1, 0, Drtciie, Dpsier2_SPEC, RW>

RTC Interval interrupt Deep Software Standby Cancel Signal Enable

pub fn drtcaie(self) -> RegisterField<3, 0x1, 1, 0, Drtcaie, Dpsier2_SPEC, RW>

RTC Alarm interrupt Deep Software Standby Cancel Signal Enable

pub fn dnmie(self) -> RegisterField<4, 0x1, 1, 0, Dnmie, Dpsier2_SPEC, RW>

NMI Pin Enable