Prcr

Type Alias Prcr 

pub type Prcr = RegValueT<Prcr_SPEC>;
Protect Register

Aliased Type

pub struct Prcr { /* private fields */ }

Implementations

Source

impl Prcr

pub fn prc0(self) -> RegisterField<0, 0x1, 1, 0, Prc0, Prc0, Prcr_SPEC, RW>

Enable writing to the registers related to the clock generation circuit

pub fn prc1(self) -> RegisterField<1, 0x1, 1, 0, Prc1, Prc1, Prcr_SPEC, RW>

Enable writing to the registers related to the low power modes

pub fn prc3(self) -> RegisterField<3, 0x1, 1, 0, Prc3, Prc3, Prcr_SPEC, RW>

Enable writing to the registers related to the LVD

pub fn prc4(self) -> RegisterField<4, 0x1, 1, 0, Prc4, Prc4, Prcr_SPEC, RW>

pub fn prkey(self) -> RegisterField<8, 0xff, 1, 0, u8, u8, Prcr_SPEC, W>

PRC Key Code